diff --git a/books/Makefile.pamphlet b/books/Makefile.pamphlet
index 31cb362..9d37f49 100644
--- a/books/Makefile.pamphlet
+++ b/books/Makefile.pamphlet
@@ -27,6 +27,7 @@ DVIPDFM=dvipdfm
 DVIPS=dvips -Ppdf
 PS2PDF=ps2pdf
 RM=rm -f
+OUT1=${MNT}/${SYS}/lib
 
 BOOKPDF=${PDF}/bookvol0.pdf    ${PDF}/bookvol1.pdf    ${PDF}/bookvol2.pdf \
         ${PDF}/bookvol3.pdf    ${PDF}/bookvol4.pdf    ${PDF}/bookvol5.pdf \
@@ -38,7 +39,7 @@ BOOKPDF=${PDF}/bookvol0.pdf    ${PDF}/bookvol1.pdf    ${PDF}/bookvol2.pdf \
         ${PDF}/bookvolbib.pdf  \
         ${PDF}/refcard.pdf     ${PDF}/endpaper.pdf    ${PDF}/rosetta.pdf
 
-all: announce ${BOOKPDF} ${PDF}/toc.pdf 
+all: announce ${BOOKPDF} ${PDF}/toc.pdf spadedit
 	@(cd ${PDF} ; ${RM} *.out *.toc *.sty *.def *.png)
 
 announce:
@@ -244,6 +245,12 @@ ${PDF}/toc.pdf: ${BOOKPDF}
 	fi )
 
 \end{chunk}
+\begin{chunk}{*}
+spadedit:
+	@echo b4 making spadedit from ${BOOK}/bookvol5 to ${OUT1}/scripts
+	@mkdir -p ${OUT1}
+	@tanglec ${BOOK}/bookvol5.pamphlet spadedit >${OUT1}/scripts/SPADEDIT
+
 \section{Combined Bibliography}
 \eject
 \begin{thebibliography}{99}
diff --git a/books/bookvol5.pamphlet b/books/bookvol5.pamphlet
index abc005c..c017e6b 100644
--- a/books/bookvol5.pamphlet
+++ b/books/bookvol5.pamphlet
@@ -19701,6 +19701,48 @@ o )read
 
 \end{chunk}
 
+\subsubsection{The SPADEDIT command}
+Axiom execute a shell script called SPADEDIT to open a file using
+the user's chosen editor. That editor name is, by convention, in
+the EDITOR shell variable. If that variable is not set we default
+to the 'vi' editor. 
+\begin{chunk}{spadedit}
+#!/bin/sh
+# this script is invoked by the spad )edit command
+# can be replaced by users favorite editor
+# optional second argument should be character offset in file
+
+thefile=$1
+if [ ! -f $1 ] ; then 
+  thefile=$AXIOM/../../src/algebra/$1
+else
+  thefile=$1
+fi
+
+
+if [ $# = 2 ] ; then
+	START=`grep -n \^$2\( $thefile | awk -F: '{print $1}'`
+else
+	START=1
+fi
+
+if [ ! "$EDITOR" ] ; then
+	EDITOR=vi
+fi
+
+if [ "$DISPLAY" ] ; then
+	if [ "$EDITOR" = "emacs" ] ; then
+		emacs  +$START $thefile &
+	elif [ "$EDITOR" = "vi" ] ; then
+		xterm -e vi +$START $thefile &
+        else
+		xterm -e $EDITOR $thefile &
+	fi
+else
+	$EDITOR $thefile
+fi
+\end{chunk}
+
 \defun{updateSourceFiles}{updateSourceFiles}
 \calls{updateSourceFiles}{pathname}
 \calls{updateSourceFiles}{pathnameName}
diff --git a/changelog b/changelog
index bab0bce..8777a17 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,8 @@
+20140801 tpd src/axiom-website/patches.html 20140801.02.tpd.patch
+20140801 tpd books/Makefile.pamphlet add spadedit
+20140801 tpd books/bookvol5.pamphlet add spadedit
+20140801 tpd src/scripts/Makefile.pamphlet remove spadedit
+20140801 tpd src/scripts/SPADEDIT deleted
 20140801 tpd src/axiom-website/patches.html 20140801.01.tpd.patch
 20140801 tpd books/Makefile.pamphlet add bbold.sty
 20140801 tpd books/bbold.sty added
diff --git a/patch b/patch
index 554b6be..4f8d4fa 100644
--- a/patch
+++ b/patch
@@ -1,3 +1,3 @@
-books/Makefile.pamphlet, bbold.sty add bbold.sty
+books/bookvol5, SPADEDIT
 
-Apparently bbold.sty is no longer shipped with texlive.
+move SPADEDIT into bookvol5 near the code that calls it.
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 3c03852..d611415 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -4596,6 +4596,8 @@ src/doc/index.html remove unused file<br/>
 src/lib/fnct-key.c remove 'save_echo', unused variable<br/>
 <a href="patches/20140801.01.tpd.patch">20140801.01.tpd.patch</a>
 books/Makefile.pamphlet, bbold.sty add bbold.sty<br/>
+<a href="patches/20140801.02.tpd.patch">20140801.02.tpd.patch</a>
+books/bookvol5, SPADEDIT, move spadedit to bookvol5<br/>
  </body>
 </html>
 
diff --git a/src/scripts/Makefile.pamphlet b/src/scripts/Makefile.pamphlet
index da2de1b..6102ca8 100644
--- a/src/scripts/Makefile.pamphlet
+++ b/src/scripts/Makefile.pamphlet
@@ -17,7 +17,7 @@ script to exist and prevent duplicate copying.
 OUT=${MNT}/${SYS}/bin
 OUT1=${MNT}/${SYS}/lib
 
-all: announce ${OUT}/document ${OUT1}/SPADEDIT
+all: announce ${OUT}/document
 
 announce:
 	@ echo ======================================
@@ -29,12 +29,6 @@ ${OUT}/document:
 	@cp -pr * ${OUT}
 	@mkdir -p ${OUT}/tex
 	@rm -f ${OUT}/Makefile*
-	@rm -f ${OUT}/SPADEDIT
-
-${OUT1}/SPADEDIT:
-	@echo 2 making ${OUT1}/SPADEDIT from ${SRC}/scripts/SPADEDIT
-	@mkdir -p ${OUT1}
-	@cp ${SRC}/scripts/SPADEDIT ${OUT1}/SPADEDIT
 
 clean:
 	@echo 2 cleaning ${SRC}/scripts
diff --git a/src/scripts/SPADEDIT b/src/scripts/SPADEDIT
deleted file mode 100755
index 8b3b4b1..0000000
--- a/src/scripts/SPADEDIT
+++ /dev/null
@@ -1,34 +0,0 @@
-#!/bin/sh
-# this script is invoked by the spad )edit command
-# can be replaced by users favorite editor
-# optional second argument should be character offset in file
-
-thefile=$1
-if [ ! -f $1 ] ; then 
-  thefile=$AXIOM/../../src/algebra/$1
-else
-  thefile=$1
-fi
-
-
-if [ $# = 2 ] ; then
-	START=`grep -n \^$2\( $thefile | awk -F: '{print $1}'`
-else
-	START=1
-fi
-
-if [ ! "$EDITOR" ] ; then
-	EDITOR=vi
-fi
-
-if [ "$DISPLAY" ] ; then
-	if [ "$EDITOR" = "emacs" ] ; then
-		emacs  +$START $thefile &
-	elif [ "$EDITOR" = "vi" ] ; then
-		xterm -e vi +$START $thefile &
-        else
-		xterm -e $EDITOR $thefile &
-	fi
-else
-	$EDITOR $thefile
-fi
